@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ using namespace KSieveUi;
 SelectMatchTypeComboBox::SelectMatchTypeComboBox(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent)
     : QComboBox(parent)
 {
-    mHasRegexCapability = sieveGraphicalModeWidget->sieveCapabilities().contains(QStringLiteral("regex"));
+    mHasRegexCapability = sieveGraphicalModeWidget->sieveCapabilities().contains(QLatin1String("regex"));
     initialize();
     connect(this, QOverload<int>::of(&SelectMatchTypeComboBox::activated), this, &SelectMatchTypeComboBox::slotValueChanged);
 }
@@ -40,7 +40,7 @@ void SelectMatchTypeComboBox::slotValueChanged(int val)
 {
     if (mHasRegexCapability) {
         const QString value = itemData(val).toString();
-        Q_EMIT switchToRegexp(value.contains(QStringLiteral("regex")));
+        Q_EMIT switchToRegexp(value.contains(QLatin1String("regex")));
     }
     Q_EMIT valueChanged();
 }
@@ -62,7 +62,7 @@ void SelectMatchTypeComboBox::initialize()
 QString SelectMatchTypeComboBox::code(bool &negative) const
 {
     QString value = itemData(currentIndex()).toString();
-    negative = value.startsWith(QStringLiteral("[NOT]"));
+    negative = value.startsWith(QLatin1String("[NOT]"));
     if (negative) {
         value = value.remove(QStringLiteral("[NOT]"));
     }
@@ -77,7 +77,7 @@ void SelectMatchTypeComboBox::setCode(const QString &code, const QString &name,
         if (mHasRegexCapability) {
             //TODO optimize
             const QString value = itemData(index).toString();
-            Q_EMIT switchToRegexp(value.contains(QStringLiteral("regex")));
+            Q_EMIT switchToRegexp(value.contains(QLatin1String("regex")));
         }
     } else {
         AutoCreateScriptUtil::comboboxItemNotFound(code, name, error);
