@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,12 +26,12 @@ class SieveActionReturn : public SieveAction
     Q_OBJECT
 public:
     explicit SieveActionReturn(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString help() const override;
-    QStringList needRequires(QWidget *parent) const override;
-    bool needCheckIfServerHasCapability() const override;
-    QString serverNeedsCapability() const override;
-    QString code(QWidget *) const override;
-    QUrl href() const override;
+    Q_REQUIRED_RESULT QString help() const override;
+    Q_REQUIRED_RESULT QStringList needRequires(QWidget *parent) const override;
+    Q_REQUIRED_RESULT bool needCheckIfServerHasCapability() const override;
+    Q_REQUIRED_RESULT QString serverNeedsCapability() const override;
+    Q_REQUIRED_RESULT QString code(QWidget *) const override;
+    Q_REQUIRED_RESULT QUrl href() const override;
 };
 }
 
