@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,7 +27,7 @@ class SieveTextEditorSpellCheckDecorator : public Sonnet::SpellCheckDecorator
     Q_OBJECT
 public:
     explicit SieveTextEditorSpellCheckDecorator(SieveTextEdit *plainTextEdit);
-    bool isSpellCheckingEnabledForBlock(const QString &textBlock) const override;
+    Q_REQUIRED_RESULT bool isSpellCheckingEnabledForBlock(const QString &textBlock) const override;
 private:
     SieveTextEdit *mPlainTextEdit = nullptr;
 };
