@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,6 +20,7 @@
 #include "kmanagesieve/sievejob.h"
 
 #include <KLocalizedString>
+#include <QDebug>
 
 using namespace KSieveUi;
 GenerateGlobalScriptJob::GenerateGlobalScriptJob(const QUrl &url, QObject *parent)
@@ -63,6 +64,7 @@ void GenerateGlobalScriptJob::start()
     writeUserScript();
 }
 
+//TODO why it's not activated ????
 void GenerateGlobalScriptJob::writeMasterScript()
 {
     const QString masterScript = QStringLiteral("# MASTER\n"
@@ -90,7 +92,7 @@ void GenerateGlobalScriptJob::writeMasterScript()
 
     QUrl url(mCurrentUrl);
     url = url.adjusted(QUrl::RemoveFilename);
-    url.setPath(url.path() + QLatin1String("MASTER"));
+    url.setPath(url.path() + QLatin1Char('/') + QLatin1String("MASTER"));
     mMasterJob = KManageSieve::SieveJob::put(url, masterScript, true, true);
     connect(mMasterJob, &KManageSieve::SieveJob::result, this, &GenerateGlobalScriptJob::slotPutMasterResult);
 }
@@ -119,12 +121,12 @@ void GenerateGlobalScriptJob::writeUserScript()
                                         "require [\"include\"];\n");
 
     for (const QString &activeScript : qAsConst(mListUserActiveScripts)) {
-        userScript += QStringLiteral("\ninclude :personal \"%1\"").arg(activeScript);
+        userScript += QStringLiteral("\ninclude :personal \"%1\";").arg(activeScript);
     }
 
     QUrl url(mCurrentUrl);
     url = url.adjusted(QUrl::RemoveFilename);
-    url.setPath(url.path() + QLatin1String("USER"));
+    url.setPath(url.path() + QLatin1Char('/') + QLatin1String("USER"));
     mUserJob = KManageSieve::SieveJob::put(url, userScript, false, false);
     connect(mUserJob, &KManageSieve::SieveJob::result, this, &GenerateGlobalScriptJob::slotPutUserResult);
 }
