@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -35,11 +35,10 @@ VacationCreateScriptJob::VacationCreateScriptJob(QObject *parent)
     , mUserJobRunning(false)
     , mScriptJobRunning(false)
     , mSuccess(true)
-    , mSieveJob(Q_NULLPTR)
-    , mParseUserJob(Q_NULLPTR)
-    , mCreateJob(Q_NULLPTR)
+    , mSieveJob(nullptr)
+    , mParseUserJob(nullptr)
+    , mCreateJob(nullptr)
 {
-
 }
 
 VacationCreateScriptJob::~VacationCreateScriptJob()
@@ -52,17 +51,17 @@ void VacationCreateScriptJob::kill()
     if (mSieveJob) {
         mSieveJob->kill();
     }
-    mSieveJob = Q_NULLPTR;
+    mSieveJob = nullptr;
 
     if (mParseUserJob) {
         mParseUserJob->kill();
     }
-    mParseUserJob = Q_NULLPTR;
+    mParseUserJob = nullptr;
 
     if (mCreateJob) {
         mCreateJob->kill();
     }
-    mParseUserJob = Q_NULLPTR;
+    mParseUserJob = nullptr;
 }
 
 void VacationCreateScriptJob::setStatus(bool activate, bool wasActive)
@@ -105,31 +104,36 @@ void VacationCreateScriptJob::start()
     }
 
     mUserJobRunning = false;
-    mScriptJobRunning = true;
-    mSieveJob = KManageSieve::SieveJob::get(mUrl);
-    mSieveJob->setInteractive(false);
-    connect(mSieveJob, &KManageSieve::SieveJob::gotScript, this, &VacationCreateScriptJob::slotGetScript);
 
     if (mKep14Support && mActivate && !mScriptActive) {
         mUserJobRunning = true;
         QUrl url = mUrl;
         url = url.adjusted(QUrl::RemoveFilename);
-        url.setPath(url.path() + QLatin1String("USER"));
+        url.setPath(url.path() + QLatin1Char('/') + QLatin1String("USER"));
         mParseUserJob = new ParseUserScriptJob(url, this);
         connect(mParseUserJob, &ParseUserScriptJob::finished, this, &VacationCreateScriptJob::slotGotActiveScripts);
         mParseUserJob->start();
+    } else {
+        createScript();
     }
 }
 
+void VacationCreateScriptJob::createScript()
+{
+    mScriptJobRunning = true;
+    mSieveJob = KManageSieve::SieveJob::get(mUrl);
+    connect(mSieveJob, &KManageSieve::SieveJob::gotScript, this, &VacationCreateScriptJob::slotGetScript);
+}
+
 void VacationCreateScriptJob::slotGetScript(KManageSieve::SieveJob *job, bool success, const QString &oldScript, bool active)
 {
     Q_UNUSED(active)
     Q_ASSERT(job == mSieveJob);
-    mSieveJob = Q_NULLPTR;
+    mSieveJob = nullptr;
     QString script = mScript;
     if (success || !oldScript.trimmed().isEmpty()) {
         script = VacationUtils::mergeRequireLine(oldScript, mScript);
-        script = VacationUtils::updateVacationBlock(oldScript, mScript);
+        script = VacationUtils::updateVacationBlock(oldScript, script);
     }
     if (mKep14Support) {
         mSieveJob = KManageSieve::SieveJob::put(mUrl, mScript, false, false);
@@ -142,7 +146,7 @@ void VacationCreateScriptJob::slotGetScript(KManageSieve::SieveJob *job, bool su
 void VacationCreateScriptJob::slotPutResult(KManageSieve::SieveJob *job, bool success)
 {
     Q_ASSERT(job == mSieveJob);
-    mSieveJob = Q_NULLPTR;
+    mSieveJob = nullptr;
     mScriptJobRunning = false;
     if (!success) {
         mSuccess = false;
@@ -156,15 +160,18 @@ void VacationCreateScriptJob::handleResult()
         return;
     }
 
-    if (mSuccess)
-        KMessageBox::information(Q_NULLPTR,  mActivate
+    if (mSuccess) {
+        KMessageBox::information(nullptr, mActivate
                                  ? i18n("Sieve script installed successfully on the server \'%1\'.\n"
                                         "Out of Office reply is now active.", mServerName)
                                  : i18n("Sieve script installed successfully on the server \'%1\'.\n"
                                         "Out of Office reply has been deactivated.", mServerName));
+    } else {
+        KMessageBox::information(nullptr, i18n("Impossible to install script on server \'%1\'", mServerName));
+    }
 
     qCDebug(LIBKSIEVE_LOG) << "( ???," << mSuccess << ", ? )";
-    mSieveJob = Q_NULLPTR; // job deletes itself after returning from this slot!
+    mSieveJob = nullptr; // job deletes itself after returning from this slot!
     Q_EMIT result(mSuccess);
     Q_EMIT scriptActive(mActivate, mServerName);
     deleteLater();
@@ -173,33 +180,34 @@ void VacationCreateScriptJob::handleResult()
 void VacationCreateScriptJob::slotGotActiveScripts(ParseUserScriptJob *job)
 {
     Q_ASSERT(job == mParseUserJob);
-    mParseUserJob = Q_NULLPTR;
+    mParseUserJob = nullptr;
     if (!job->error().isEmpty()) {
         slotGenerateDone(job->error());
         return;
     }
 
     QStringList list = job->activeScriptList();
-
     if (!list.contains(mUrl.fileName())) {
         list.prepend(mUrl.fileName());
-        mCreateJob = new GenerateGlobalScriptJob(mUrl, this);
-        mCreateJob->addUserActiveScripts(list);
-        connect(mCreateJob, &GenerateGlobalScriptJob::success, [ = ]() {
-            this->slotGenerateDone();
-        });
-        connect(mCreateJob, &GenerateGlobalScriptJob::error, this, &VacationCreateScriptJob::slotGenerateDone);
-        mCreateJob->start();
     }
+    mCreateJob = new GenerateGlobalScriptJob(mUrl, this);
+    mCreateJob->addUserActiveScripts(list);
+    connect(mCreateJob, &GenerateGlobalScriptJob::success, [=]() {
+        this->slotGenerateDone();
+    });
+    connect(mCreateJob, &GenerateGlobalScriptJob::error, this, &VacationCreateScriptJob::slotGenerateDone);
+    mCreateJob->start();
 }
 
 void VacationCreateScriptJob::slotGenerateDone(const QString &error)
 {
-    mCreateJob = Q_NULLPTR;
+    mCreateJob = nullptr;
     mUserJobRunning = false;
     if (!error.isEmpty()) {
         qCWarning(LIBKSIEVE_LOG) << error;
         mSuccess = false;
+        handleResult();
+    } else {
+        createScript();
     }
-    handleResult();
 }
