@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -52,6 +52,7 @@ typedef QVector<AddrSpec> AddrSpecList;
 namespace KSieveUi {
 class VacationMailActionWidget;
 class SieveImapAccountSettings;
+class VacationMailLineEdit;
 class VacationEditWidget : public QWidget
 {
     Q_OBJECT
@@ -74,7 +75,7 @@ public:
     int notificationInterval() const;
     void setNotificationInterval(int days);
 
-    KMime::Types::AddrSpecList mailAliases() const;
+    KMime::Types::AddrSpecList mailAliases(bool &ok) const;
     void setMailAliases(const KMime::Types::AddrSpecList &aliases);
     void setMailAliases(const QString &aliases);
 
@@ -100,7 +101,7 @@ public:
     void setEndTime(const QTime &endTime);
 
     VacationUtils::MailAction mailAction() const;
-    QString mailActionRecipient() const;
+    QString mailActionRecipient(bool &valid) const;
     void setMailAction(VacationUtils::MailAction action, const QString &recipient);
     void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account);
 
@@ -113,7 +114,7 @@ private Q_SLOTS:
 protected:
     QCheckBox *mActiveCheck = nullptr;
     QSpinBox *mIntervalSpin = nullptr;
-    QLineEdit *mMailAliasesEdit = nullptr;
+    VacationMailLineEdit *mMailAliasesEdit = nullptr;
     KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
     QCheckBox *mSpamCheck = nullptr;
     QCheckBox *mDomainCheck = nullptr;
