@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -170,7 +170,7 @@ void ManageSieveWidget::slotContextMenuRequested(const QPoint &p)
     } else if (!item->parent()) {
         // top-levels:
         const bool jobsListIsEmpty = mJobs.keys(item).isEmpty();
-        if (!serverHasError(item) && jobsListIsEmpty) {
+        if (canAddNewScript(item, jobsListIsEmpty)) {
             menu.addAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New Script..."), this, &ManageSieveWidget::slotNewScript);
         } else if (!jobsListIsEmpty) { //In Progress
             menu.addAction(KStandardGuiItem::cancel().icon(), KStandardGuiItem::cancel().text(), this, &ManageSieveWidget::slotCancelFetch);
@@ -181,6 +181,24 @@ void ManageSieveWidget::slotContextMenuRequested(const QPoint &p)
     }
 }
 
+bool ManageSieveWidget::canAddNewScript(QTreeWidgetItem *item, bool jobsListIsEmpty)
+{
+    if (!serverHasError(item) && jobsListIsEmpty) {
+        if (item->parent()) {
+            item = item->parent();
+        }
+        if (!item) {
+            return false;
+        }
+
+        if (!mUrls.count(item)) {
+            return false;
+        }
+        return true;
+    }
+    return false;
+}
+
 void ManageSieveWidget::slotCancelFetch()
 {
     QTreeWidgetItem *item = d->mTreeView->currentItem();
@@ -189,6 +207,8 @@ void ManageSieveWidget::slotCancelFetch()
         for (KManageSieve::SieveJob *job : jobs) {
             job->kill(KJob::EmitResult);
         }
+    } else {
+        qCWarning(LIBKSIEVE_LOG) << "ManageSieveWidget::slotCancelFetch(): item is not selected";
     }
 }
 
@@ -337,7 +357,7 @@ void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate)
         GenerateGlobalScriptJob *job = new GenerateGlobalScriptJob(u);
         job->addUserActiveScripts(activeScripts);
         connect(job, &GenerateGlobalScriptJob::success, this, &ManageSieveWidget::slotRefresh);
-        connect(job, &GenerateGlobalScriptJob::error, this, &ManageSieveWidget::slotRefresh);
+        connect(job, &GenerateGlobalScriptJob::error, this, &ManageSieveWidget::slotGenerateGlobalScriptError);
         job->start();
         return;
     }
@@ -359,6 +379,12 @@ void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate)
     connect(job, &KManageSieve::SieveJob::result, this, &ManageSieveWidget::slotRefresh);
 }
 
+void ManageSieveWidget::slotGenerateGlobalScriptError(const QString &errorStr)
+{
+    qCWarning(LIBKSIEVE_LOG) << "MManageSieveWidget::slotGenerateGlobalScriptError: error: " << errorStr;
+    slotRefresh();
+}
+
 bool ManageSieveWidget::itemIsActived(QTreeWidgetItem *item) const
 {
     Q_ASSERT(item && item->parent());
@@ -550,16 +576,18 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
     }
     d->mBlockSignal = false;
 
-    const bool hasKep14EditorMode = Util::hasKep14Support(job->sieveCapabilities(), listScript, activeScript);
+    bool hasKep14EditorMode = Util::hasKep14Support(job->sieveCapabilities(), listScript, activeScript);
     if (hasKep14EditorMode) {
         QUrl u = mUrls[parent];
         u = u.adjusted(QUrl::RemoveFilename);
-        u.setPath(u.path() + QStringLiteral("USER"));
+        u.setPath(u.path() + QLatin1Char('/') + QStringLiteral("USER"));
         ParseUserScriptJob *parseJob = new ParseUserScriptJob(u);
         parseJob->setProperty("parentItem", QVariant::fromValue<QTreeWidgetItem *>(parent));
         connect(parseJob, &ParseUserScriptJob::finished, this, &ManageSieveWidget::setActiveScripts);
         parseJob->start();
         (static_cast<SieveTreeWidgetItem *>(parent))->startAnimation();
+    } else if (Util::hasKep14CapabilitySupport(job->sieveCapabilities())) { //We don't have user script but server support kep14
+        hasKep14EditorMode = true;
     }
 
     parent->setData(0, SIEVE_SERVER_CAPABILITIES, job->sieveCapabilities());
